@@ -866,7 +866,7 @@ makehtml(int total)
 		free(name);
 	}
 #endif
-	gp = gfind_open(dbpath, NULL, other_files ? GPATH_BOTH : GPATH_SOURCE);
+	gp = gfind_open(dbpath, NULL, other_files ? GPATH_BOTH : GPATH_SOURCE, 0);
 	while ((path = gfind_read(gp)) != NULL) {
 		if (gp->type == GPATH_OTHER)
 			fputc(' ', anchor_stream);
@@ -881,7 +881,7 @@ makehtml(int total)
 	/*
 	 * For each path in GPATH, convert the path into HTML file.
 	 */
-	gp = gfind_open(dbpath, NULL, other_files ? GPATH_BOTH : GPATH_SOURCE);
+	gp = gfind_open(dbpath, NULL, other_files ? GPATH_BOTH : GPATH_SOURCE, 0);
 	while ((path = gfind_read(gp)) != NULL) {
 		char html[MAXPATHLEN];
 
@@ -1141,13 +1141,11 @@ configuration(void)
 	if (getconfb("colorize_warned_line"))
 		colorize_warned_line = 1;
 	strbuf_reset(sb);
-	strbuf_reset(sb);
 	if (getconfs("include_file_suffixes", sb))
 		include_file_suffixes = check_strdup(strbuf_value(sb));
 	strbuf_reset(sb);
 	if (getconfs("langmap", sb))
 		langmap = check_strdup(strbuf_value(sb));
-	strbuf_reset(sb);
 	strbuf_close(sb);
 }
 /**
@@ -1247,7 +1245,7 @@ main(int argc, char **argv)
 	openconf(cwdpath);
 	configuration();
 	/*
-	 * Setup langmap
+	 * setup_langmap() is needed to use decide_lang().
 	 */
 	setup_langmap(langmap);
 	save_environment(argc, argv);
@@ -1569,7 +1567,7 @@ main(int argc, char **argv)
          * other than source file. The oflag requires new version of GPATH.
 	 */
 	if (other_files) {
-		GFIND *gp = gfind_open(dbpath, NULL, 0);
+		GFIND *gp = gfind_open(dbpath, NULL, 0, 0);
 		if (gp->version < 2)
 			die("GPATH is old format. Please remake it by invoking gtags(1).");
 		gfind_close(gp);
