@@ -367,17 +367,18 @@ Cpp(const struct parser_param *param)
 		case CPP_UNION:
 			while ((c = nexttoken(interested, cpp_reserved_word)) == CPP___ATTRIBUTE__)
 				process_attribute(param);
+			while (c == '\n')
+				c = nexttoken(interested, cpp_reserved_word);
 			if (c == SYMBOL) {
 				if (peekc(0) == '{') /* } */ {
 					PUT(PARSER_DEF, token, lineno, sp);
-					do {
-						c = nexttoken(interested, cpp_reserved_word);
-					} while (c == '\n');
 				} else {
 					PUT(PARSER_REF_SYM, token, lineno, sp);
-					c = nexttoken(interested, cpp_reserved_word);
 				}
+				c = nexttoken(interested, cpp_reserved_word);
 			}
+			while (c == '\n')
+				c = nexttoken(interested, cpp_reserved_word);
 			if (c == '{' /* } */ && cc == CPP_ENUM) {
 				enumerator_list(param);
 			} else {
@@ -464,19 +465,19 @@ Cpp(const struct parser_param *param)
 
 					while ((c = nexttoken(interest_enum, cpp_reserved_word)) == CPP___ATTRIBUTE__)
 						process_attribute(param);
+					while (c == '\n')
+						c = nexttoken(interest_enum, cpp_reserved_word);
 					/* read tag name if exist */
 					if (c == SYMBOL) {
 						if (peekc(0) == '{') /* } */ {
 							PUT(PARSER_DEF, token, lineno, sp);
-							do {
-								c = nexttoken(interest_enum, cpp_reserved_word);
-							} while (c == '\n');
 						} else {
 							PUT(PARSER_REF_SYM, token, lineno, sp);
-							c = nexttoken(interest_enum, cpp_reserved_word);
 						}
 						c = nexttoken(interest_enum, cpp_reserved_word);
 					}
+					while (c == '\n')
+						c = nexttoken(interest_enum, cpp_reserved_word);
 					if (c_ == CPP_ENUM) {
 						if (c == '{') /* } */
 							c = enumerator_list(param);
