@@ -1,5 +1,5 @@
 /* ANSI-C code produced by gperf version 3.0.3 */
-/* Command-line: gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=asm_hash --lookup-fn-name=asm_lookup  */
+/* Command-line: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=asm_hash --lookup-fn-name=asm_lookup  */
 /* Computed positions: -k'3,5' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -108,7 +108,7 @@ asm_hash (register const char *str, register unsigned int len)
       33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
       33, 33, 33, 33, 33, 33
     };
-  register int hval = (int)len;
+  register unsigned int hval = len;
 
   switch (hval)
     {
@@ -160,9 +160,9 @@ asm_lookup (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = asm_hash (str, len);
+      unsigned int key = asm_hash (str, len);
 
-      if (key <= MAX_HASH_VALUE && key >= 0)
+      if (key <= MAX_HASH_VALUE)
         {
           register const char *s = wordlist[key].name;
 
