@@ -1,5 +1,5 @@
 /* ANSI-C code produced by gperf version 3.0.3 */
-/* Command-line: gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=cpp_hash --lookup-fn-name=cpp_lookup  */
+/* Command-line: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=cpp_hash --lookup-fn-name=cpp_lookup  */
 /* Computed positions: -k'2-4' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -176,7 +176,7 @@ cpp_hash (register const char *str, register unsigned int len)
       243, 243, 243, 243, 243, 243, 243, 243, 243, 243,
       243, 243, 243, 243, 243, 243, 243
     };
-  register int hval = (int)len;
+  register unsigned int hval = len;
 
   switch (hval)
     {
@@ -344,9 +344,9 @@ cpp_lookup (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = cpp_hash (str, len);
+      unsigned int key = cpp_hash (str, len);
 
-      if (key <= MAX_HASH_VALUE && key >= 0)
+      if (key <= MAX_HASH_VALUE)
         {
           register const char *s = wordlist[key].name;
 
