@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2010, 2011
+ * Copyright (c) 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2010, 2011,
+ *	2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -45,6 +46,7 @@
 #include "locatestring.h"
 #include "queue.h"
 #include "strbuf.h"
+#include "strmake.h"
 #include "test.h"
 
 #define NOTFUNCTION	".notfunction"
@@ -178,6 +180,11 @@ load_plugin_parser(const char *pluginspec)
 		/* Assume a single-character name is a drive letter. */
 		if (q == lt_dl_name + 1)
 			q = strchr(q + 1, ':');
+#else
+		/* skip quoted ':' */
+		while (q && *q == ':' && *(q - 1) == '\\') {
+			q = strchr(q + 1, ':');
+		}
 #endif
 		if (q == NULL) {
 			parser_name = "parser";
@@ -187,6 +194,9 @@ load_plugin_parser(const char *pluginspec)
 				die_with_code(2, "syntax error in pluginspec '%s'.", pluginspec);
 			parser_name = q;
 		}
+#ifndef _WIN32
+		strremovechar((char *)lt_dl_name, '\\');
+#endif
 #if defined(_WIN32) && !defined(__CYGWIN__)
 		/* Bypass libtool and load the DLL directly, relative to us. */
 		pent->handle = (lt_dlhandle)LoadLibrary(lt_dl_name);
@@ -214,8 +224,18 @@ load_plugin_parser(const char *pluginspec)
 		pent->entry.parser = (PVOID)GetProcAddress((HINSTANCE)pent->handle, parser_name);
 #else
 		pent->handle = lt_dlopen(lt_dl_name);
-		if (pent->handle == NULL)
-			die_with_code(2, "cannot open shared object '%s'.", lt_dl_name);
+		if (pent->handle == NULL) {
+			/*
+			 * Retry after removing the extension, because some packages
+			 * don't have '.la' files.
+			 */
+			q = strrchr(lt_dl_name, '.');
+			if (q)
+				*q = '\0';
+			pent->handle = lt_dlopenext(lt_dl_name);
+			if (pent->handle == NULL)
+				die_with_code(2, "cannot open shared object '%s'.", lt_dl_name);
+		}
 		pent->entry.lt_dl_name = lt_dl_name;
 		pent->entry.parser = lt_dlsym(pent->handle, parser_name);
 #endif
