@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010
+ * Copyright (c) 2010, 2015
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -83,11 +83,17 @@ copy_langmap_converting_cpp(char *dst, const char *src)
 #include <fcntl.h>
 static HANDLE pid;
 static char argv[] = "ctags "
-#ifdef USE_TYPE_STRING
-	"--gtags "
+#if defined(USE_EXTRA_FIELDS)
+	"--_xformat=%R %-16N %4n %-16F %C",
+	"--extra=+r",
+	"--fields=+r",
+#else
+	"--format=1",
 #endif
-	"-xu --filter --filter-terminator=" TERMINATOR "\n "
-	"--format=1 " LANGMAP_OPTION;
+	"-xu",
+	"--filter",
+	"--filter-terminator=" TERMINATOR "\n",
+	LANGMAP_OPTION;
 static void
 start_ctags(const struct parser_param *param)
 {
@@ -148,13 +154,16 @@ static pid_t pid;
 static char *argv[] = {
 	EXUBERANT_CTAGS,
 	NULL,
-#ifdef USE_TYPE_STRING
-	"--gtags",
+#if defined(USE_EXTRA_FIELDS)
+	"--_xformat=%R %-16N %4n %-16F %C",
+	"--extra=+r",
+	"--fields=+r",
+#else
+	"--format=1",
 #endif
 	"-xu",
 	"--filter",
 	"--filter-terminator=" TERMINATOR "\n",
-	"--format=1",
 	NULL
 };
 static void
@@ -248,13 +257,13 @@ put_line(char *ctags_x, const struct parser_param *param)
 	int type = PARSER_DEF;
 	char *p, *tagname, *filename;
 
-#ifdef USE_TYPE_STRING
+#if defined(USE_EXTRA_FIELDS)
 	/*
 	 * Output of ctags:
 	 * ctags -x ...
 	 * main              326 global/global.c  main(int argc, char **argv)
 	 *
-	 * ctags -x --gtags ...
+	 * ctags -x --_xformat="%R %-16N %4n %-16F %C" --extra=+r --fields=+r
 	 * D main              326 global/global.c  main(int argc, char **argv)
 	 */
 	switch (*ctags_x) {
